@@ -1,6 +1,5 @@
 use super::*;
-use std::cmp::Ordering;
-use std::fmt;
+use std::{cmp::Ordering, fmt};
 
 #[derive(Debug, Eq)]
 pub struct AddressKey {
@@ -32,6 +31,8 @@ impl InterpretableFrom<String> for AddressKey {
         let mut value = [0u8; 32];
         if bytes.len() == 32 {
             value.copy_from_slice(&bytes[..]);
+        } else {
+            panic!("account address is not 32 bytes in length");
         }
         AddressKey {
             value,
@@ -58,6 +59,8 @@ impl InterpretableFrom<ValueSubTree> for AddressValue {
         let mut value = [0u8; 32];
         if bytes.len() == 32 {
             value.copy_from_slice(&bytes[..]);
+        } else {
+            panic!("account address is not 32 bytes in length");
         }
         AddressValue {
             value,
