@@ -4,12 +4,16 @@ mod account_raw;
 mod account_raw_check;
 mod address;
 mod context;
+mod esdt_check;
+mod esdt_raw_check;
 mod functions;
 mod logs;
 mod logs_raw;
 mod parse_util;
 mod scenario;
 mod scenario_raw;
+mod storage_check;
+mod storage_raw_check;
 mod value;
 mod value_check;
 mod value_interpreter;
@@ -22,11 +26,15 @@ pub use account_raw::*;
 pub use account_raw_check::*;
 pub use address::*;
 pub use context::*;
+pub use esdt_check::*;
+pub use esdt_raw_check::*;
 pub use logs::*;
 pub use logs_raw::*;
 pub use parse_util::*;
 pub use scenario::*;
 pub use scenario_raw::*;
+pub use storage_check::*;
+pub use storage_raw_check::*;
 pub use value::*;
 pub use value_check::*;
 pub use value_interpreter::*;
